
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.012.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.3601"
  },
  "configure_requires" => {
    "Module::Build" => "0.3601"
  },
  "dist_abstract" => "Catmandu modules for working with ArXiv data.",
  "dist_author" => [
    "=over"
  ],
  "dist_name" => "Catmandu-ArXiv",
  "dist_version" => "0.212",
  "license" => "perl",
  "module_name" => "Catmandu::ArXiv",
  "recursive_test_files" => 1,
  "requires" => {
    "Catmandu" => "1.09",
    "Catmandu::Identifier" => "0.06",
    "Catmandu::XML" => "0.16",
    "Furl" => "3.07",
    "IO::Socket::SSL" => "2.059",
    "Moo" => 0,
    "URI" => 0,
    "XML::LibXML" => 0,
    "XML::LibXSLT" => 0,
    "perl" => "v5.10.1"
  },
  "test_requires" => {
    "Test::Exception" => "0.32",
    "Test::More" => "0.88"
  }
);


my %fallback_build_requires = (
  "Module::Build" => "0.3601",
  "Test::Exception" => "0.32",
  "Test::More" => "0.88"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
