package Catmandu::ArXiv;

our $VERSION = '0.212';

=head1 NAME

Catmandu::ArXiv - Catmandu modules for working with ArXiv data.

=begin markdown

[![Build Status](https://travis-ci.org/LibreCat/Catmandu-ArXiv.svg?branch=master)](https://travis-ci.org/LibreCat/Catmandu-ArXiv)
[![Coverage](https://coveralls.io/repos/LibreCat/Catmandu-ArXiv/badge.png?branch=master)](https://coveralls.io/r/LibreCat/Catmandu-ArXiv)
[![CPANTS kwalitee](http://cpants.cpanauthors.org/dist/Catmandu-ArXiv.png)](http://cpants.cpanauthors.org/dist/Catmandu-ArXiv)

=end markdown

=head1 MODULES

=over

=item * L<Catmandu::Importer::ArXiv>

=back

=head1 AUTHOR

=over

=item * Wouter Willaert

=item * Vitali Peil

=back

=head1 MAINTAINER

=over

=item * Vitali Peil

=item * Christian Pietsch

=back

=head1 LICENSE AND COPYRIGHT

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See http://dev.perl.org/licenses/ for more information.

=cut

1;
